Product
=======

.. currentmodule:: pqp.expression

.. autoclass:: Product
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Product.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: to_latex
